==> mc_automation_tools-0.0.33-py3-none-any.whl: mc_automation_tools/base_requests.py <==
# pylint: disable=line-too-long, invalid-name
"""
This module wrapping http protocol request sending [get, post and etc.]
"""
import logging
import json
import requests
from mc_automation_tools import common
from mc_automation_tools.configuration import config
_log = logging.getLogger('automation_tools.requests')


def send_post_request(url, body={}, header=None):
    """ send http post request by providing post full url + body , header is optional, by default:content-type': 'application/json',
    "accept": "*/* """
    common.url_validator(url)
    if not header:
        header = {'content-type': 'application/json', "accept": "*/*"}
    try:
        if not config.CERT_DIR:
            resp = requests.post(url=url, data=json.dumps(body), headers=header)
        else:
            resp = requests.post(url=url, data=json.dumps(body), headers=header, verify=config.CERT_DIR)
        _log.debug("response code: %d", resp.status_code)
        _log.debug("response message: %s", resp.text)

    except Exception as e:
        _log.error('failed get response with error: %s and error of content:', str(e))
        raise requests.exceptions.RequestException('failed on getting response data from get response with error '
                                                   'message: %s' % str(e))

    return resp


def send_get_request(url, params=None):
    """
    send http get request by providing get full url
    :param url: url to get request
    :param params: json with key-value of query params
    :return: http response data as request library returns
    """
    common.url_validator(url)
    try:
        if not config.CERT_DIR:
            resp = requests.get(url, params)
        else:
            resp = requests.get(url, params,verify=config.CERT_DIR, timeout=120)
        _log.debug("response code: %d", resp.status_code)
        _log.debug("response message: %s", resp.content)

    except Exception as e:
        _log.error('failed get response with error: %s', str(e))
        raise requests.exceptions.RequestException("failed on getting response data from get response with error "
                                                   "message: %s" % str(e))

    return resp


def send_get_request2(url, params=None):
    """
    send http get request by providing get full url.
    This method is similar to <send_get_request> method except the way to provide params ->
        It provide params into "data" argument instead of "params" on regular method
    :param url: url to get request
    :param params: json with key-value of query params
    :return: http response data as request library returns
    """
    common.url_validator(url)
    try:
        if not config.CERT_DIR:
            resp = requests.get(url, data=params)
        else:
            resp = requests.get(url, data=params, verify=config.CERT_DIR, timeout=120)
        _log.debug("response code: %d", resp.status_code)
        _log.debug("response message: %s", resp.content)

    except Exception as e:
        _log.error('failed get response with error: %s', str(e))
        raise requests.exceptions.RequestException("failed on getting response data from get response with error "
                                                   "message: %s" % str(e))

    return resp


def send_put_request(url, data):
    """
    send http put request by providing put url + body
    :param url: url to get request
    :param data: json with key-value of query params
    :return: http response data as request library returns
    """
    common.url_validator(url)
    try:
        if not config.CERT_DIR:
            resp = requests.get(url, data=data)
        else:
            resp = requests.get(url, data=data, verify=config.CERT_DIR, timeout=120)
        _log.debug("response code: %d", resp.status_code)
        _log.debug("response message: %s", resp.content)

    except Exception as e:
        _log.error('failed get response with error: %s', str(e))
        raise requests.exceptions.RequestException("failed on getting response data from get response with error "
                                                   "message: %s" % str(e))

    return resp

==> mc_automation_tools-0.0.34-py3-none-any.whl: mc_automation_tools/base_requests.py <==
# pylint: disable=line-too-long, invalid-name
"""
This module wrapping http protocol request sending [get, post and etc.]
"""
import logging
import json
import requests
from mc_automation_tools import common
from mc_automation_tools.configuration import config
_log = logging.getLogger('automation_tools.requests')


def send_post_request(url, body={}, header=None):
    """ send http post request by providing post full url + body , header is optional, by default:content-type': 'application/json',
    "accept": "*/* """
    common.url_validator(url)
    if not header:
        header = {'content-type': 'application/json', "accept": "*/*"}
    try:
        if not config.CERT_DIR:
            resp = requests.post(url=url, data=json.dumps(body), headers=header)
        else:
            resp = requests.post(url=url, data=json.dumps(body), headers=header, verify=config.CERT_DIR)
        _log.debug("response code: %d", resp.status_code)
        _log.debug("response message: %s", resp.text)

    except Exception as e:
        _log.error('failed get response with error: %s and error of content:', str(e))
        raise requests.exceptions.RequestException('failed on getting response data from get response with error '
                                                   'message: %s' % str(e))

    return resp


def send_get_request(url, params=None):
    """
    send http get request by providing get full url
    :param url: url to get request
    :param params: json with key-value of query params
    :return: http response data as request library returns
    """
    common.url_validator(url)
    try:
        if not config.CERT_DIR:
            resp = requests.get(url, params)
        else:
            resp = requests.get(url, params,verify=config.CERT_DIR, timeout=120)
        _log.debug("response code: %d", resp.status_code)
        _log.debug("response message: %s", resp.content)

    except Exception as e:
        _log.error('failed get response with error: %s', str(e))
        raise requests.exceptions.RequestException("failed on getting response data from get response with error "
                                                   "message: %s" % str(e))

    return resp


def send_get_request2(url, params=None):
    """
    send http get request by providing get full url.
    This method is similar to <send_get_request> method except the way to provide params ->
        It provide params into "data" argument instead of "params" on regular method
    :param url: url to get request
    :param params: json with key-value of query params
    :return: http response data as request library returns
    """
    common.url_validator(url)
    try:
        if not config.CERT_DIR:
            resp = requests.get(url, data=params)
        else:
            resp = requests.get(url, data=params, verify=config.CERT_DIR, timeout=120)
        _log.debug("response code: %d", resp.status_code)
        _log.debug("response message: %s", resp.content)

    except Exception as e:
        _log.error('failed get response with error: %s', str(e))
        raise requests.exceptions.RequestException("failed on getting response data from get response with error "
                                                   "message: %s" % str(e))

    return resp


def send_put_request(url, data):
    """
    send http put request by providing put url + body
    :param url: url to get request
    :param data: json with key-value of query params
    :return: http response data as request library returns
    """
    common.url_validator(url)
    try:
        if not config.CERT_DIR:
            resp = requests.put(url, data=data, timeout=120)
        else:
            resp = requests.put(url, data=data, verify=config.CERT_DIR, timeout=120)
        _log.debug("response code: %d", resp.status_code)
        _log.debug("response message: %s", resp.content)

    except Exception as e:
        _log.error('failed get response with error: %s', str(e))
        raise requests.exceptions.RequestException("failed on getting response data from get response with error "
                                                   "message: %s" % str(e))

    return resp
